pub enum PositionEncodingKind {
    UTF8,
    UTF16,
    UTF32,
}
A type indicating how positions are encoded, specifically what column offsets mean.

Variants

UTF8

Character offsets count UTF-8 code units.

UTF16

Character offsets count UTF-16 code units.

This is the default and must always be supported by servers.

UTF32

Character offsets count UTF-32 code units.

Implementation note: these are the same as Unicode code points, so this PositionEncodingKind may also be used for an encoding-agnostic representation of character offsets.