pub struct InitializeParams {
pub process_id: Option<i64>,
pub client_info: Option<ClientInfo>,
pub locale: Option<String>,
pub root_path: Option<Option<String>>,
pub root_uri: Option<DocumentUri>,
pub initialization_options: Option<LSPAny>,
pub capabilities: ClientCapabilities,
pub trace: Option<TraceValue>,
pub workspace_folders: Option<Option<Vec<WorkspaceFolder>>>,
}Fields
process_id: Option<i64>The process Id of the parent process that started the server. Is null if the process has not been started by another process. If the parent process is not alive then the server should exit (see exit notification) its process.
client_info: Option<ClientInfo>Information about the client
locale: Option<String>The locale the client is currently showing the user interface in. This must not necessarily be the locale of the operating system.
Uses IETF language tags as the value’s syntax (See https://en.wikipedia.org/wiki/IETF_language_tag)
root_path: Option<Option<String>>in favour of root_uri
The root path of the workspace. Is null if no folder is open.
root_uri: Option<DocumentUri>in favour of workspace_folders
The rootUri of the workspace. Is null if no folder is open. If both root_path and root_uri are set, root_uri wins.
initialization_options: Option<LSPAny>User provided initialization options.
capabilities: ClientCapabilitiesThe capabilities provided by the client.
trace: Option<TraceValue>The initial trace setting. If omitted trace is disabled ('off').
workspace_folders: Option<Option<Vec<WorkspaceFolder>>>The workspace folders configured in the client when the server starts.
This property is only available if the client supports workspace folders.
It can be null if the client supports workspace folders but none are
configured.